from os.path import abspath, dirname

ROOT_DIR = dirname(abspath(__file__))

__version__ = "1.0.3"
__author__ = "Moxie"
